Stan Math Library: stan/math/fwd/scal/fun/cos.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

cos.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_COS_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_COS_HPP
3
4 #include <stan/math/fwd/core.hpp>
5 #include <cmath>
6
7 namespace stan {
8 namespace math {
9
10 template <typename T>
11 inline
12 fvar<T>
13 cos(const fvar<T>& x) {
14 using std::sin;
15 using std::cos;
16 return fvar<T>(cos(x.val_), x.d_ * -sin(x.val_));
17 }
18
19 }
20 }
21 #endif
stan::math::cos
fvar< T > cos(const fvar< T > &x)
Definition: cos.hpp:13
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan::math::cos
var cos(const var &a)
Return the cosine of a radian-scaled variable (cmath).
Definition: cos.hpp:49
stan
Definition: log_sum_exp.hpp:8
stan::math::sin
fvar< T > sin(const fvar< T > &x)
Definition: sin.hpp:14
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.